================
Iotanbo Py Utils
================

.. start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |travis| |appveyor|
        | |codecov|
    * - package
      - | |commits-since|

.. |travis| image:: https://api.travis-ci.org/iotanbo/iotanbo_py_utils.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/iotanbo/iotanbo_py_utils

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/iotanbo/iotanbo_py_utils?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/iotanbo/iotanbo_py_utils

.. |codecov| image:: https://codecov.io/github/iotanbo/iotanbo_py_utils/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/iotanbo/iotanbo_py_utils

.. |commits-since| image:: https://img.shields.io/github/commits-since/iotanbo/iotanbo_py_utils/v0.0.6.svg
    :alt: Commits since latest release
    :target: https://github.com/iotanbo/iotanbo_py_utils/compare/v0.0.6...master



.. end-badges

Python utility collection by iotanbo

* Free software: MIT license

Overview
=============
This is a small convenience python library that allows working with files, strings, console etc.
Initially it was developed for internal usage with other 'iotanbo' projects, so the documentation
is rather brief. You can see usage examples in the tests.

Installation
============

::

    pip install iotanbo_py_utils

You can also install the in-development version with::

    pip install https://github.com/iotanbo/iotanbo_py_utils/archive/master.zip


